PyQCstrc - Python tools for Quasi-Crystal structure
===================================================

Main websites:

 * https://github.com/ttyamada/PyQCstrc


Getting PyQCstrc
-------------

PyQCstrc is available from `PyPI <https://pypi.python.org/pypi/pyqcstrc>`_.

Requirements
-------------

- Cython>=0.29.21
- numpy>=1.20.1
- scipy>=1.6.0

Citation:
---------

'PyQCstrc.icosah: A computing toolkit for structure model of icosahedral quasicrystals; T. Yamada, in prep.`_

Design Specifications
---------------------

Name: 
.....

PyQCstrc = Python tools for Quasi-Crystal structure



